==> dif-database-repository-2.7.1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/ReportTemplateAreaTrans.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;


import java.util.ArrayList;
import java.util.List;
import org.hibernate.Session;
import pt.digitalis.dif.model.dataset.HibernateDataSet;
import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.dif.model.hibernate.HibernateUtil;
import pt.digitalis.dif.model.utils.AbstractBeanRelationsAttributes;
import pt.digitalis.dif.model.utils.IBeanAttributesDataSet;

/**
 * ReportTemplateAreaTrans
* Generated on ORM Generator
* DIF build process for the Model layer
*
*/
@SuppressWarnings("serial")
public class ReportTemplateAreaTrans extends AbstractBeanRelationsAttributes implements java.io.Serializable, IBeanAttributesDataSet<ReportTemplateAreaTrans> {

    /** ReportTemplateAreaTrans attributes enumeration */
    public static class Fields
    {
        /** id column */
        public static final String ID ="id";
        /** language column */
        public static final String LANGUAGE ="language";
        /** content column */
        public static final String CONTENT ="content";
        /** title column */
        public static final String TITLE ="title";

        /**
         * List of existing fields
         *
         * @return list of field names
         */
        public static List<String> values()
        {
            ArrayList<String> list = new ArrayList<String>();
            list.add("id");
            list.add("language");
            list.add("content");
            list.add("title");

            return list;
        }
    }

    /** Field attributes */
    public static ReportTemplateAreaTransFieldAttributes FieldAttributes=new ReportTemplateAreaTransFieldAttributes();

    /**
    * @return the field attributes definitions
    */
    @Override public ReportTemplateAreaTransFieldAttributes getDefinitions()
    {
        return FieldAttributes;
    }

    /**
     * The Class Relations.
     */
    public class Relations extends AbstractBeanRelationsAttributes.AbstractRelations
    {

        /**
        * Instantiates a new relations.
        *
        * @param currentPath the current path
        */
        public Relations(String currentPath)
        {
            super(currentPath);
        }
        /**
         * reportTemplateArea relation.
         *
         * @return the reportTemplateArea bean relations attributes.
         */
        public ReportTemplateArea.Relations reportTemplateArea()
        {
            ReportTemplateArea c = new ReportTemplateArea();
            return c.new Relations(this.buildPath("reportTemplateArea"));
        }

        /**
         * the ID path.
         *
         * @return the path
         */
        public String ID()
        {
            return buildPath(Fields.ID);
        }
        /**
         * the LANGUAGE path.
         *
         * @return the path
         */
        public String LANGUAGE()
        {
            return buildPath(Fields.LANGUAGE);
        }
        /**
         * the CONTENT path.
         *
         * @return the path
         */
        public String CONTENT()
        {
            return buildPath(Fields.CONTENT);
        }
        /**
         * the TITLE path.
         *
         * @return the path
         */
        public String TITLE()
        {
            return buildPath(Fields.TITLE);
        }
    }

    /** The dummy obj. */
    private static ReportTemplateAreaTrans dummyObj=new ReportTemplateAreaTrans();

    /**
     * Get ReportTemplateAreaTrans Relations .
     *
     * @return the relations
     */
    public static Relations FK()
    {
        return dummyObj.new Relations(null);
    }

    /**
    * Gets a new dataSet object for this bean
    *
    * @return the dataSet
    */
    public IDataSet<ReportTemplateAreaTrans> getDataSet()
    {
        return new HibernateDataSet<ReportTemplateAreaTrans>(ReportTemplateAreaTrans.class, HibernateUtil.getSessionFactory("DIFRepository"),
            ReportTemplateAreaTrans.getPKFieldListAsString(), ReportTemplateAreaTrans.FieldAttributes);
    }

    /**
    * Gets a new dataSet object for this bean
    *
    * @return the dataSet
    */
    public static IDataSet<ReportTemplateAreaTrans> getDataSetInstance()
    {
        return new ReportTemplateAreaTrans().getDataSet();
    }

    /**
    * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeNoGraphNavigation(java.lang.String)
    */
    @Override protected Object getAttributeNoGraphNavigation(String attributeName)
    {
        if("id".equalsIgnoreCase(attributeName))
            return id;
        if("reportTemplateArea".equalsIgnoreCase(attributeName))
            return reportTemplateArea;
        if("language".equalsIgnoreCase(attributeName))
            return language;
        if("content".equalsIgnoreCase(attributeName))
            return content;
        if("title".equalsIgnoreCase(attributeName))
            return title;

        return null;
    }

    /**
    * @see pt.digitalis.utils.common.IBeanAttributes#setAttribute(java.lang.String, java.lang.Object)
    */
    public void setAttribute(String attributeName,Object attributeValue)
    {
        if("id".equalsIgnoreCase(attributeName))
            id =(Long)attributeValue;
        if("reportTemplateArea".equalsIgnoreCase(attributeName))
            reportTemplateArea =(ReportTemplateArea)attributeValue;
        if("language".equalsIgnoreCase(attributeName))
            language =(String)attributeValue;
        if("content".equalsIgnoreCase(attributeName))
            content =(String)attributeValue;
        if("title".equalsIgnoreCase(attributeName))
            title =(String)attributeValue;
    }

    // Fields

    /** id private attribute */
    private Long id;

    /** reportTemplateArea private attribute */
    private ReportTemplateArea reportTemplateArea;

    /** language private attribute */
    private String language;

    /** content private attribute */
    private String content;

    /** title private attribute */
    private String title;

    /** The pojo's primary key field list names */
    private static List<String> pkFieldList;

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
     public synchronized static List<String> getPKFieldList()
     {
         if (pkFieldList == null)
         {
             pkFieldList = new ArrayList<String>();
             pkFieldList.add("id");
         }

         return pkFieldList;
     }

    /**
     * Get the table fields that compose the PK as a comma separated field name list
     *
     * @return the PK field list as a string
     */
     public static String getPKFieldListAsString()
     {
         StringBuffer buffer = new StringBuffer();

         for (int i = 0; i < getPKFieldList().size(); i++)
         {
             if (i != 0)
                 buffer.append(",");

             buffer.append(getPKFieldList().get(i));
         }

         return buffer.toString();
     }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeAsString(java.lang.String)
     */
     @Override
     public String getAttributeAsString(String attributeName)
     {

        Object value = getAttribute(attributeName);

        if (value == null)
            return "";
        else {
            return value.toString().trim();
        }
     }

    // Constructors

    /**
     * default constructor
     */
    public ReportTemplateAreaTrans() {
    }

	/** 
	 * minimal constructor
	 *
     * @param reportTemplateArea the reportTemplateArea
     * @param content the content
     * @param title the title
    }
	 */
    public ReportTemplateAreaTrans(ReportTemplateArea reportTemplateArea, String content, String title) {
        this.reportTemplateArea = reportTemplateArea;
        this.content = content;
        this.title = title;
    }

    /**
     * full constructor
	 *
     * @param reportTemplateArea the reportTemplateArea
     * @param language the language
     * @param content the content
     * @param title the title
     */
    public ReportTemplateAreaTrans(ReportTemplateArea reportTemplateArea, String language, String content, String title) {
        this.reportTemplateArea = reportTemplateArea;
        this.language = language;
        this.content = content;
        this.title = title;
    }

    // Property accessors
    
    /**       
     * id getter method
     *
     * @return id method
     */
    public Long getId() {
        return this.id;
    }
    
    /**       
     * id setter method
     *
     * @param id the id
     *
     * @return ReportTemplateAreaTrans modified instance
     */
    public ReportTemplateAreaTrans setId(Long id) {
        this.id = id;
        
        return this;
    }
    /**       
     * reportTemplateArea getter method
     *
     * @return reportTemplateArea method
     */
    public ReportTemplateArea getReportTemplateArea() {
        return this.reportTemplateArea;
    }
    
    /**       
     * reportTemplateArea setter method
     *
     * @param reportTemplateArea the reportTemplateArea
     *
     * @return ReportTemplateAreaTrans modified instance
     */
    public ReportTemplateAreaTrans setReportTemplateArea(ReportTemplateArea reportTemplateArea) {
        this.reportTemplateArea = reportTemplateArea;
        
        return this;
    }
    /**       
     * language getter method
     *
     * @return language method
     */
    public String getLanguage() {
        return this.language;
    }
    
    /**       
     * language setter method
     *
     * @param language the language
     *
     * @return ReportTemplateAreaTrans modified instance
     */
    public ReportTemplateAreaTrans setLanguage(String language) {
        this.language = language;
        
        return this;
    }
    /**       
     * content getter method
     *
     * @return content method
     */
    public String getContent() {
        return this.content;
    }
    
    /**       
     * content setter method
     *
     * @param content the content
     *
     * @return ReportTemplateAreaTrans modified instance
     */
    public ReportTemplateAreaTrans setContent(String content) {
        this.content = content;
        
        return this;
    }
    /**       
     * title getter method
     *
     * @return title method
     */
    public String getTitle() {
        return this.title;
    }
    
    /**       
     * title setter method
     *
     * @param title the title
     *
     * @return ReportTemplateAreaTrans modified instance
     */
    public ReportTemplateAreaTrans setTitle(String title) {
        this.title = title;
        
        return this;
    }

    /**
     * Creates a String representation of the ReportTemplateAreaTrans object
     *
     * @return the compiled String
     */
    @Override
    public String toString() {
	    StringBuffer buffer = new StringBuffer();

        buffer.append(getClass().getName()).append("@").append(Integer.toHexString(hashCode())).append(" [");

        buffer.append("id").append("='").append(getId()).append("' ");			
        buffer.append("language").append("='").append(getLanguage()).append("' ");			
        buffer.append("content").append("='").append(getContent()).append("' ");			
        buffer.append("title").append("='").append(getTitle()).append("' ");			
        buffer.append("]");
      
        return buffer.toString();
    }

    /**
     * Compares the String representation of the ReportTemplateAreaTrans object
     *
     * @param other The object to compare to
     *
     * @return true of the objects are equal
     */
    public boolean equals(ReportTemplateAreaTrans other) {
        	return this.toString().equals(other.toString());
    }
    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttributeFromString(java.lang.String, java.lang.String)
     */
    public void setAttributeFromString(String attributeName, String attributeValue) {
        if ("id".equalsIgnoreCase(attributeName))
            this.id = Long.valueOf(attributeValue);

        if ("language".equalsIgnoreCase(attributeName))
        	this.language = attributeValue;

        if ("content".equalsIgnoreCase(attributeName))
        	this.content = attributeValue;

        if ("title".equalsIgnoreCase(attributeName))
        	this.title = attributeValue;

    }


    /**
     * Instanciates an Hibernate proxy data object (does not load it from the database, provides lazy load for that)
     *
     * @param session the session
     * @param id      the id
     *
     * @return the proxy
     */
    public static ReportTemplateAreaTrans getProxy(Session session, Long id)
    {
        return(ReportTemplateAreaTrans)session.load(ReportTemplateAreaTrans.class,id);
    }

    /**
    * Instanciates an Hibernate proxy data object (does not load it from the database, provides lazy load for that)
    *
    * @param id      the id
    *
    * @return the proxy
    */
    public static ReportTemplateAreaTrans getProxy(Long id)
    {
        Session session = HibernateUtil.getSessionFactory("DIFRepository").getCurrentSession();
        boolean wasActive = session.getTransaction().isActive();

        if (!wasActive)
            session.beginTransaction();

        ReportTemplateAreaTrans result = (ReportTemplateAreaTrans)session.load(ReportTemplateAreaTrans.class,id);

        if (!wasActive)
            session.getTransaction().commit();

        return result;
    }


    /**
     * Instanciates an Hibernate data object
     *
     * @param session the session
     * @param id      the id
     *
     * @return the instance
     */
    public static ReportTemplateAreaTrans getInstance(Session session, Long id)
    {
        return(ReportTemplateAreaTrans)session.get(ReportTemplateAreaTrans.class,id);
    }

    /**
    * Instanciates an Hibernate data object
    *
    * @param id      the id
    *
    * @return the instance
    */
    public static ReportTemplateAreaTrans getInstance(Long id)
    {
        Session session = HibernateUtil.getSessionFactory("DIFRepository").getCurrentSession();
        boolean wasActive = session.getTransaction().isActive();

        if (!wasActive)
            session.beginTransaction();

        ReportTemplateAreaTrans result = (ReportTemplateAreaTrans)session.get(ReportTemplateAreaTrans.class,id);

        if (!wasActive)
            session.getTransaction().commit();

        return result;
    }

}

==> dif-database-repository-2.7.3-5-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/ReportTemplateAreaTrans.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;


import java.util.ArrayList;
import java.util.List;
import org.hibernate.Session;
import pt.digitalis.dif.model.dataset.HibernateDataSet;
import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.dif.model.hibernate.HibernateUtil;
import pt.digitalis.dif.model.utils.AbstractBeanRelationsAttributes;
import pt.digitalis.dif.model.utils.IBeanAttributesDataSet;

/**
 * ReportTemplateAreaTrans
* Generated on ORM Generator
* DIF build process for the Model layer
*
*/
@SuppressWarnings("serial")
public class ReportTemplateAreaTrans extends AbstractBeanRelationsAttributes implements java.io.Serializable, IBeanAttributesDataSet<ReportTemplateAreaTrans> {

    /**
    * Constant with the session factory ID
    */
    public static String SESSION_FACTORY_NAME = "DIFRepository";

    /** ReportTemplateAreaTrans attributes enumeration */
    public static class Fields
    {
        /** id column */
        public static final String ID ="id";
        /** language column */
        public static final String LANGUAGE ="language";
        /** content column */
        public static final String CONTENT ="content";
        /** title column */
        public static final String TITLE ="title";

        /**
         * List of existing fields
         *
         * @return list of field names
         */
        public static List<String> values()
        {
            ArrayList<String> list = new ArrayList<String>();
            list.add("id");
            list.add("language");
            list.add("content");
            list.add("title");

            return list;
        }
    }

    /** Field attributes */
    public static ReportTemplateAreaTransFieldAttributes FieldAttributes=new ReportTemplateAreaTransFieldAttributes();

    /**
    * @return the field attributes definitions
    */
    @Override public ReportTemplateAreaTransFieldAttributes getDefinitions()
    {
        return FieldAttributes;
    }

    /**
     * The Class Relations.
     */
    public class Relations extends AbstractBeanRelationsAttributes.AbstractRelations
    {

        /**
        * Instantiates a new relations.
        *
        * @param currentPath the current path
        */
        public Relations(String currentPath)
        {
            super(currentPath);
        }
        /**
         * reportTemplateArea relation.
         *
         * @return the reportTemplateArea bean relations attributes.
         */
        public ReportTemplateArea.Relations reportTemplateArea()
        {
            ReportTemplateArea c = new ReportTemplateArea();
            return c.new Relations(this.buildPath("reportTemplateArea"));
        }

        /**
         * the ID path.
         *
         * @return the path
         */
        public String ID()
        {
            return buildPath(Fields.ID);
        }
        /**
         * the LANGUAGE path.
         *
         * @return the path
         */
        public String LANGUAGE()
        {
            return buildPath(Fields.LANGUAGE);
        }
        /**
         * the CONTENT path.
         *
         * @return the path
         */
        public String CONTENT()
        {
            return buildPath(Fields.CONTENT);
        }
        /**
         * the TITLE path.
         *
         * @return the path
         */
        public String TITLE()
        {
            return buildPath(Fields.TITLE);
        }
    }

    /** The dummy obj. */
    private static ReportTemplateAreaTrans dummyObj=new ReportTemplateAreaTrans();

    /**
     * Get ReportTemplateAreaTrans Relations .
     *
     * @return the relations
     */
    public static Relations FK()
    {
        return dummyObj.new Relations(null);
    }

    /**
    * Gets a new dataSet object for this bean
    *
    * @return the dataSet
    */
    public IDataSet<ReportTemplateAreaTrans> getDataSet()
    {
        return getDataSetInstance();
    }

    /**
    * Gets a new dataSet object for this bean
    *
    * @return the dataSet
    */
    public static IDataSet<ReportTemplateAreaTrans> getDataSetInstance()
    {
        return new HibernateDataSet<ReportTemplateAreaTrans>(ReportTemplateAreaTrans.class, HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME),
            ReportTemplateAreaTrans.getPKFieldListAsString(), ReportTemplateAreaTrans.FieldAttributes);
    }

    /**
    * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeNoGraphNavigation(java.lang.String)
    */
    @Override protected Object getAttributeNoGraphNavigation(String attributeName)
    {
        if("id".equalsIgnoreCase(attributeName))
            return id;
        if("reportTemplateArea".equalsIgnoreCase(attributeName))
            return reportTemplateArea;
        if("language".equalsIgnoreCase(attributeName))
            return language;
        if("content".equalsIgnoreCase(attributeName))
            return content;
        if("title".equalsIgnoreCase(attributeName))
            return title;

        return null;
    }

    /**
    * @see pt.digitalis.utils.common.IBeanAttributes#setAttribute(java.lang.String, java.lang.Object)
    */
    public void setAttribute(String attributeName,Object attributeValue)
    {
        if("id".equalsIgnoreCase(attributeName))
            id =(Long)attributeValue;
        if("reportTemplateArea".equalsIgnoreCase(attributeName))
            reportTemplateArea =(ReportTemplateArea)attributeValue;
        if("language".equalsIgnoreCase(attributeName))
            language =(String)attributeValue;
        if("content".equalsIgnoreCase(attributeName))
            content =(String)attributeValue;
        if("title".equalsIgnoreCase(attributeName))
            title =(String)attributeValue;
    }

    // Fields

    /** id private attribute */
    private Long id;

    /** reportTemplateArea private attribute */
    private ReportTemplateArea reportTemplateArea;

    /** language private attribute */
    private String language;

    /** content private attribute */
    private String content;

    /** title private attribute */
    private String title;

    /** The pojo's primary key field list names */
    private static List<String> pkFieldList;

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
     public synchronized static List<String> getPKFieldList()
     {
         if (pkFieldList == null)
         {
             pkFieldList = new ArrayList<String>();
             pkFieldList.add("id");
         }

         return pkFieldList;
     }

    /**
     * Get the table fields that compose the PK as a comma separated field name list
     *
     * @return the PK field list as a string
     */
     public static String getPKFieldListAsString()
     {
         StringBuffer buffer = new StringBuffer();

         for (int i = 0; i < getPKFieldList().size(); i++)
         {
             if (i != 0)
                 buffer.append(",");

             buffer.append(getPKFieldList().get(i));
         }

         return buffer.toString();
     }

    /**
     * Gets description field.
     *
     * @return the description field
     */
    @Override
    public String getDescriptionField()
    {
        return FieldAttributes.getDescriptionField();
    }

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
    @Override
    public List<String> getPKFields()
    {
        return getPKFieldList();
    }

    /**
     * Is composite PK.
     *
     * @return the boolean
     */
    @Override
    public boolean isCompositePK()
    {
        return this.getPKFieldList().size() > 1;
    }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeAsString(java.lang.String)
     */
     @Override
     public String getAttributeAsString(String attributeName)
     {
        if (attributeName.contains("."))
        {
            return this.getAttributeAsStringParseBeanPath(attributeName);
        }
        else
        {
            Object value = getAttribute(attributeName);

            if (value == null)
                return "";
            else {
                return value.toString().trim();
            }
        }
     }

    // Constructors

    /**
     * default constructor
     */
    public ReportTemplateAreaTrans() {
    }

	/** 
	 * minimal constructor
	 *
     * @param reportTemplateArea the reportTemplateArea
     * @param content the content
     * @param title the title
    }
	 */
    public ReportTemplateAreaTrans(ReportTemplateArea reportTemplateArea, String content, String title) {
        this.reportTemplateArea = reportTemplateArea;
        this.content = content;
        this.title = title;
    }

    /**
     * full constructor
	 *
     * @param reportTemplateArea the reportTemplateArea
     * @param language the language
     * @param content the content
     * @param title the title
     */
    public ReportTemplateAreaTrans(ReportTemplateArea reportTemplateArea, String language, String content, String title) {
        this.reportTemplateArea = reportTemplateArea;
        this.language = language;
        this.content = content;
        this.title = title;
    }

    // Property accessors
    
    /**       
     * id getter method
     *
     * @return id method
     */
    public Long getId() {
        return this.id;
    }
    
    /**       
     * id setter method
     *
     * @param id the id
     *
     * @return ReportTemplateAreaTrans modified instance
     */
    public ReportTemplateAreaTrans setId(Long id) {
        this.id = id;
        
        return this;
    }
    /**       
     * reportTemplateArea getter method
     *
     * @return reportTemplateArea method
     */
    public ReportTemplateArea getReportTemplateArea() {
        return this.reportTemplateArea;
    }
    
    /**       
     * reportTemplateArea setter method
     *
     * @param reportTemplateArea the reportTemplateArea
     *
     * @return ReportTemplateAreaTrans modified instance
     */
    public ReportTemplateAreaTrans setReportTemplateArea(ReportTemplateArea reportTemplateArea) {
        this.reportTemplateArea = reportTemplateArea;
        
        return this;
    }
    /**       
     * language getter method
     *
     * @return language method
     */
    public String getLanguage() {
        return this.language;
    }
    
    /**       
     * language setter method
     *
     * @param language the language
     *
     * @return ReportTemplateAreaTrans modified instance
     */
    public ReportTemplateAreaTrans setLanguage(String language) {
        this.language = language;
        
        return this;
    }
    /**       
     * content getter method
     *
     * @return content method
     */
    public String getContent() {
        return this.content;
    }
    
    /**       
     * content setter method
     *
     * @param content the content
     *
     * @return ReportTemplateAreaTrans modified instance
     */
    public ReportTemplateAreaTrans setContent(String content) {
        this.content = content;
        
        return this;
    }
    /**       
     * title getter method
     *
     * @return title method
     */
    public String getTitle() {
        return this.title;
    }
    
    /**       
     * title setter method
     *
     * @param title the title
     *
     * @return ReportTemplateAreaTrans modified instance
     */
    public ReportTemplateAreaTrans setTitle(String title) {
        this.title = title;
        
        return this;
    }

    /**
     * reportTemplateArea id getter method
     *
     * @return reportTemplateArea id method
     */
    public Long getReportTemplateAreaId() {
        if (this.reportTemplateArea == null)
            return null;
        else
            return this.reportTemplateArea.getId();
    }

    /**
     * ReportTemplateArea proxy setter method from id.
     *
     * @return ReportTemplateAreaTrans modified instance
     */
    public ReportTemplateAreaTrans setReportTemplateAreaProxyFromId(Long id)
    {
        if (id == null || id.equals(-1L))
            this.reportTemplateArea = null;
        else
            this.reportTemplateArea = ReportTemplateArea.getProxy(id);

        return this;
    }

    /**
     * ReportTemplateArea instance setter method from id.
     *
     * @return ReportTemplateAreaTrans modified instance
     */
    public ReportTemplateAreaTrans setReportTemplateAreaInstanceFromId(Long id)
    {
        if (id == null || id.equals(-1L))
            this.reportTemplateArea = null;
        else
            this.reportTemplateArea = ReportTemplateArea.getInstance(id);

        return this;
    }

    /**
     * Creates a String representation of the ReportTemplateAreaTrans object
     *
     * @return the compiled String
     */
    @Override
    public String toString() {
	    StringBuffer buffer = new StringBuffer();

        buffer.append(getClass().getName()).append("@").append(Integer.toHexString(hashCode())).append(" [");

        buffer.append("id").append("='").append(getId()).append("' ");			
        buffer.append("language").append("='").append(getLanguage()).append("' ");			
        buffer.append("content").append("='").append(getContent()).append("' ");			
        buffer.append("title").append("='").append(getTitle()).append("' ");			
        buffer.append("]");
      
        return buffer.toString();
    }

    /**
     * Compares the String representation of the ReportTemplateAreaTrans object
     *
     * @param other The object to compare to
     *
     * @return true of the objects are equal
     */
    public boolean equals(ReportTemplateAreaTrans other) {
        	return this.toString().equals(other.toString());
    }
    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttributeFromString(java.lang.String, java.lang.String)
     */
    public void setAttributeFromString(String attributeName, String attributeValue) {
        if ("id".equalsIgnoreCase(attributeName))
            this.id = Long.valueOf(attributeValue);

        if ("language".equalsIgnoreCase(attributeName))
        	this.language = attributeValue;

        if ("content".equalsIgnoreCase(attributeName))
        	this.content = attributeValue;

        if ("title".equalsIgnoreCase(attributeName))
        	this.title = attributeValue;

    }


    /**
     * Instanciates an Hibernate proxy data object (does not load it from the database, provides lazy load for that)
     *
     * @param session the session
     * @param id      the id
     *
     * @return the proxy
     */
    public static ReportTemplateAreaTrans getProxy(Session session, Long id)
    {
        return(ReportTemplateAreaTrans)session.load(ReportTemplateAreaTrans.class,id);
    }

    /**
    * Instanciates an Hibernate proxy data object (does not load it from the database, provides lazy load for that)
    *
    * @param id      the id
    *
    * @return the proxy
    */
    public static ReportTemplateAreaTrans getProxy(Long id)
    {
        Session session = HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME).getCurrentSession();
        boolean wasActive = session.getTransaction().isActive();

        if (!wasActive)
            session.beginTransaction();

        ReportTemplateAreaTrans result = (ReportTemplateAreaTrans)session.load(ReportTemplateAreaTrans.class,id);

        if (!wasActive)
            session.getTransaction().commit();

        return result;
    }


    /**
     * Instanciates an Hibernate data object
     *
     * @param session the session
     * @param id      the id
     *
     * @return the instance
     */
    public static ReportTemplateAreaTrans getInstanceForSession(Session session, Long id)
    {
        return(ReportTemplateAreaTrans)session.get(ReportTemplateAreaTrans.class,id);
    }

    /**
    * Instanciates an Hibernate data object
    *
    * @param id      the id
    *
    * @return the instance
    */
    public static ReportTemplateAreaTrans getInstance(Long id)
    {
        Session session = HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME).getCurrentSession();
        boolean wasActive = session.getTransaction().isActive();

        if (!wasActive)
            session.beginTransaction();

        ReportTemplateAreaTrans result = (ReportTemplateAreaTrans)session.get(ReportTemplateAreaTrans.class,id);

        if (!wasActive)
            session.getTransaction().commit();

        return result;
    }

}
